% example Quokka3 settingsfile
% 25.7% efficient record TOPCon unit-cell from A. Richter et al., "n-Type Si solar cells with passivating electron contact: Identifying sources for efficiency limitations by wafer thickness and resistivity variation", SOLMAT 2017
% MIS contact model from A. Fell et al., "Adaption of Basic Metal-Insulator-Semiconductor (MIS) Theory for Passivating Contacts within Numerical Solar Cell Modelling", JPV 2018
%
% (c) 2022 Andreas Fell
%
% uses the simplified 'front and rear contact unit cell' syntax
% rear TOPCon layer is modelled by a lumped skin with MIS-type vertical resistivity


Syntax = 'front and rear contact unit cell';

Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'fine'; % 'fine' required for convergence of bad MIS contact (thick oxide)
Solver.Electrical.VocGuess = 0.7;

Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298;

Sweep.Enable = 0;
% Sweep.NGroups = 1;
% Sweep.GroupA(1).Parameter = 'FullRearSkin.Layer(2).Interface.Insulator.Thickness';
% Sweep.GroupA(1).Values = [1.2 2.2];


UnitCellType = 'standard';
CellThickness = 200;
FrontContactShape = 'line';
FrontMetalShape = 'H-pattern';
FrontContactPitch = 833; % pitch of front fingers
FrontFingerWidth = 11; % [?m] full width of front fingers
FrontFingerShadingFraction = 0.7;
FrontContactWidth = 8; %[?m] full width of contact opening underneath fingers
FrontContact.OhmicResistivity = 4e-4; % [Ohmcm2]

RearContactShape = 'full';
RearMetalShape = 'full';

RearContact.OhmicResistivity = 1e-6; % set to low value when using detailed skin MIS contact model (e.g. 1e-6)

FrontMetalPolarity = 'p-type';
RearMetalPolarity = 'n-type';

Thermal.T = 298;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 1;
Bulk.Electrical.Recombination.Type = 'intrinsic';

ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 0.1; % [Ohm.cm2]
ExternalCircuit.Rshunt = 3.5e3; % [Ohm.cm2]
ExternalCircuit.DiodeJ0 = 0; % [A/cm2]
ExternalCircuit.DiodeIdeality = 1; % []

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'TOPCon_Text.csv';
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'parameterization';
Optical.TextZ.FrontZ.Z0 = 30.69;
Optical.TextZ.FrontZ.Zinf = 1.567;
Optical.TextZ.FrontZ.Zp = 1.631;

% full area front skin properties (p+ emitter)
FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 3;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 9e-15;

% local front skin properties (p++ emitter)
LocalFrontSkin.Enable = 1;
LocalFrontSkin.Width = 10;
LocalFrontSkin.ElectricalModelType = 'lumped';
LocalFrontSkin.Lumped.Electrical.RsheetEnable = 1;
LocalFrontSkin.Lumped.Electrical.Rsheet = 15;
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 90e-15;
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 300e-15;


% full rear skin properties (TOPCon)
FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 1;
FullRearSkin.Lumped.Electrical.Rsheet = 10; % Rsheet doesn't matter for full-area contact
FullRearSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullRearSkin.Lumped.Electrical.ContactedRecombination.J0 = 4e-15;
FullRearSkin.Lumped.Electrical.VerticalResistivityEnable = 1;
FullRearSkin.Lumped.Electrical.VerticalResistivity.CurrentTransportModel = 'MIS';
FullRearSkin.Lumped.Electrical.VerticalResistivity.SchottkyBarrier = 0.17;
FullRearSkin.Lumped.Electrical.VerticalResistivity.TunnelThickness = 2.3 nm; % set to e.g. 2.1 to produce a non-ohmic contact resistivity and a S-shaped JV-curve
FullRearSkin.Lumped.Electrical.VerticalResistivity.TunnelBarrier = 3.2;
FullRearSkin.Lumped.Electrical.VerticalResistivity.EffectiveMass = 0.27;
FullRearSkin.Lumped.Electrical.VerticalResistivity.OhmicResistivity = 20; % ohmic contact resistivity for electrons parallel to MIS transport (e.g. pinholes)



