% example Quokka3 settingsfile
% 25.7% efficient record TOPCon unit-cell from A. Richter et al., "n-Type Si solar cells with passivating electron contact: Identifying sources for efficiency limitations by wafer thickness and resistivity variation", SOLMAT 2017
% MIS contact model from A. Fell et al., "Adaption of Basic Metal-Insulator-Semiconductor (MIS) Theory for Passivating Contacts within Numerical Solar Cell Modelling", JPV 2018
%
% (c) 2021 Andreas Fell
%
% uses the simplified 'front and rear contact unit cell' syntax
% 'detailed' defines an MIS-type contact with a too thick oxide layer producing an S-shaped JV-curve


Syntax = 'front and rear contact unit cell';

Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'standard'; % 'very fine' required for convergence of bad MIS contact (thick oxide)
Solver.Electrical.VocGuess = 0.7;

Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298;

Sweep.Enable = 1;
Sweep.NGroups = 1;
Sweep.GroupA(1).Parameter = 'FullRearSkin.Layer(2).Interface.Insulator.Thickness';
Sweep.GroupA(1).Values = [1.2 2.2];


UnitCellType = 'standard';
CellThickness = 200;
FrontContactShape = 'line';
FrontMetalShape = 'H-pattern';
FrontContactPitch = 833; % pitch of front fingers
FrontFingerWidth = 11; % [m] full width of front fingers
FrontFingerShadingFraction = 0.7;
FrontContactWidth = 8; %[m] full width of contact opening underneath fingers
FrontContact.OhmicResistivity = 4e-4; % [Ohmcm2]

RearContactShape = 'full';
RearMetalShape = 'full';

RearContact.OhmicResistivity = 1e-6; % set to low value when using detailed skin MIS contact model (e.g. 1e-6)

FrontMetalPolarity = 'p-type';
RearMetalPolarity = 'n-type';

Thermal.T = 298;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 1;
Bulk.Electrical.Recombination.Type = 'intrinsic';

ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 0.1; % [Ohm.cm2]
ExternalCircuit.Rshunt = 3.5e3; % [Ohm.cm2]
ExternalCircuit.DiodeJ0 = 0; % [A/cm2]
ExternalCircuit.DiodeIdeality = 1; % []

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'TOPCon_Text.csv';
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'parameterization';
Optical.TextZ.FrontZ.Z0 = 30.69;
Optical.TextZ.FrontZ.Zinf = 1.567;
Optical.TextZ.FrontZ.Zp = 1.631;

% full area front skin properties (p+ emitter)
FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 300;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 9e-15;

% local front skin properties (p++ emitter)
LocalFrontSkin.Enable = 1;
LocalFrontSkin.Width = 10;
LocalFrontSkin.ElectricalModelType = 'lumped';
LocalFrontSkin.Lumped.Electrical.RsheetEnable = 1;
LocalFrontSkin.Lumped.Electrical.Rsheet = 15;
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 90e-15;
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 300e-15;


% full rear skin properties (TOPCon)
FullRearSkin.ElectricalModelType = 'detailed';
% lumped TOPCon properties:
% FullRearSkin.Lumped.Electrical.RsheetEnable = 1;
% FullRearSkin.Lumped.Electrical.Rsheet = 10; % Rsheet doesn't matter for full-area contact
% FullRearSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
% FullRearSkin.Lumped.Electrical.ContactedRecombination.J0 = 4e-15;
% detailed TOPCon properties:
FullRearSkin.Detailed.Multiscale.ModelType = 'full'; % 'full' required for accounting for vertical resistivity within a detailed skin, here from MIS model
FullRearSkin.Detailed.Multiscale.TextureMultiplier = 1.0; % 1 for flat surface
FullRearSkin.Layer(1).Name = 'in-diffusion';
FullRearSkin.Layer(1).Type = 'near-surface';
FullRearSkin.Layer(1).DopingProfile.Type = 'off'; % doping into c-Si is neglected
FullRearSkin.Layer(1).SurfaceRecombination.Type = 'S';
FullRearSkin.Layer(1).SurfaceRecombination.Sn = 1e2; % guess only
FullRearSkin.Layer(1).SurfaceRecombination.Sp = 1e2; % guess only
FullRearSkin.Layer(1).SurfaceRecombination.Et_Ei = 0;
FullRearSkin.Layer(2).Name = 'poly-Si';
FullRearSkin.Layer(2).Type = 'transport';
FullRearSkin.Layer(2).Material = 'Si';
FullRearSkin.Layer(2).ConductionType = 'n-type';
FullRearSkin.Layer(2).Thickness = 100 nm;
FullRearSkin.Layer(2).Interface.BarrierHeightType = 'user'; % an "interface" of a layer is always to the layer with the lower index, i.e. between this poly-Si layer and the near-surface layer (the c-Si bulk material)
FullRearSkin.Layer(2).Interface.BarrierHeight = 0.17;
FullRearSkin.Layer(2).Interface.Insulator.Enable = 1;
FullRearSkin.Layer(2).Interface.Insulator.Thickness = 1.2 nm;
FullRearSkin.Layer(2).Interface.Insulator.ElectronBarrier = 3.2;
FullRearSkin.Layer(2).Interface.Insulator.ElectronEffectiveMass = 0.27;
FullRearSkin.Layer(2).Interface.Insulator.RelativePermittivity = 3.9;
FullRearSkin.Layer(2).Interface.OhmicResistivity = 20;



